==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/client/infrastructure/particle/SoulBaseParticle.java <==
package com.zurrtum.create.client.infrastructure.particle;

import com.zurrtum.create.client.content.equipment.bell.SoulPulseEffect;
import net.minecraft.class_2338;
import net.minecraft.class_2400;
import net.minecraft.class_4002;
import net.minecraft.class_4184;
import net.minecraft.class_5819;
import net.minecraft.class_638;
import net.minecraft.class_7833;
import org.joml.Quaternionf;

public class SoulBaseParticle extends CustomRotationParticle {

    public SoulBaseParticle(
        class_2400 parameters,
        class_4002 spriteSet,
        class_638 worldIn,
        double x,
        double y,
        double z,
        double vx,
        double vy,
        double vz,
        class_5819 random
    ) {
        super(worldIn, x, y, z, spriteSet, 0);
        this.field_17867 = 0.5f;
        this.method_3080(this.field_17867, this.field_17867);
        this.loopLength = 16 + (int) (random.method_43057() * 2f - 1f);
        this.field_3847 = (int) (90.0F / (random.method_43057() * 0.36F + 0.64F));
        this.selectSpriteLoopingWithAge(field_17866);
        this.field_21507 = true; // disable movement
    }

    @Override
    public void method_3070() {
        selectSpriteLoopingWithAge(field_17866);

        class_2338 pos = class_2338.method_49637(field_3874, field_3854, field_3871);
        if (field_3866++ >= field_3847 || !SoulPulseEffect.isDark(field_3851, pos))
            method_3085();
    }

    @Override
    public Quaternionf getCustomRotation(class_4184 camera, float partialTicks) {
        return class_7833.field_40714.rotationDegrees(-90);
    }
}

==> create-fly-6.0.7-1.21.8-19-sources.jar: com/zurrtum/create/client/infrastructure/particle/SoulBaseParticle.java <==
package com.zurrtum.create.client.infrastructure.particle;

import com.zurrtum.create.client.content.equipment.bell.SoulPulseEffect;
import net.minecraft.class_2338;
import net.minecraft.class_2400;
import net.minecraft.class_4002;
import net.minecraft.class_4184;
import net.minecraft.class_638;
import net.minecraft.class_7833;
import org.joml.Quaternionf;

public class SoulBaseParticle extends CustomRotationParticle {

    public SoulBaseParticle(
        class_2400 parameters,
        class_4002 spriteSet,
        class_638 worldIn,
        double x,
        double y,
        double z,
        double vx,
        double vy,
        double vz
    ) {
        super(worldIn, x, y, z, spriteSet, 0);
        this.field_17867 = 0.5f;
        this.method_3080(this.field_17867, this.field_17867);
        this.loopLength = 16 + (int) (this.field_3840.method_43057() * 2f - 1f);
        this.field_3847 = (int) (90.0F / (this.field_3840.method_43057() * 0.36F + 0.64F));
        this.selectSpriteLoopingWithAge(field_17866);
        this.field_21507 = true; // disable movement
    }

    @Override
    public void method_3070() {
        selectSpriteLoopingWithAge(field_17866);

        class_2338 pos = class_2338.method_49637(field_3874, field_3854, field_3871);
        if (field_3866++ >= field_3847 || !SoulPulseEffect.isDark(field_3851, pos))
            method_3085();
    }

    @Override
    public Quaternionf getCustomRotation(class_4184 camera, float partialTicks) {
        return class_7833.field_40714.rotationDegrees(90);
    }
}
